summaryrefslogtreecommitdiffstats
path: root/remote/components
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-19 01:14:29 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-19 01:14:29 +0000
commitfbaf0bb26397aa498eb9156f06d5a6fe34dd7dd8 (patch)
tree4c1ccaf5486d4f2009f9a338a98a83e886e29c97 /remote/components
parentReleasing progress-linux version 124.0.1-1~progress7.99u1. (diff)
downloadfirefox-fbaf0bb26397aa498eb9156f06d5a6fe34dd7dd8.tar.xz
firefox-fbaf0bb26397aa498eb9156f06d5a6fe34dd7dd8.zip
Merging upstream version 125.0.1.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'remote/components')
-rw-r--r--remote/components/RemoteAgent.sys.mjs14
-rw-r--r--remote/components/nsIRemoteAgent.idl3
2 files changed, 6 insertions, 11 deletions
diff --git a/remote/components/nsIRemoteAgent.idl b/remote/components/nsIRemoteAgent.idl
index 89d637bed2..173be75a6e 100644
--- a/remote/components/nsIRemoteAgent.idl
+++ b/remote/components/nsIRemoteAgent.idl
@@ -30,7 +30,4 @@ interface nsIRemoteAgent : nsISupports
%{C++
#define NS_REMOTEAGENT_CONTRACTID "@mozilla.org/remote/agent;1"
-#define NS_REMOTEAGENT_CID \
- { 0x8f685a9d, 0x8181, 0x46d6, \
- { 0xa7, 0x1d, x86, x92, x89, x09, x9c, x6d } }
%}
diff --git a/remote/components/RemoteAgent.sys.mjs b/remote/components/RemoteAgent.sys.mjs
index c16b8c44b8..4807a8a0e0 100644
--- a/remote/components/RemoteAgent.sys.mjs
+++ b/remote/components/RemoteAgent.sys.mjs
@@ -9,6 +9,8 @@ ChromeUtils.defineESModuleGetters(lazy, {
Deferred: "chrome://remote/content/shared/Sync.sys.mjs",
HttpServer: "chrome://remote/content/server/httpd.sys.mjs",
Log: "chrome://remote/content/shared/Log.sys.mjs",
+ RecommendedPreferences:
+ "chrome://remote/content/shared/RecommendedPreferences.sys.mjs",
WebDriverBiDi: "chrome://remote/content/webdriver-bidi/WebDriverBiDi.sys.mjs",
});
@@ -31,7 +33,6 @@ const DEFAULT_PORT = 9222;
const isRemote =
Services.appinfo.processType == Services.appinfo.PROCESS_TYPE_CONTENT;
-
class RemoteAgentParentProcess {
#allowHosts;
#allowOrigins;
@@ -166,7 +167,7 @@ class RemoteAgentParentProcess {
handle(cmdLine) {
// remote-debugging-port has to be consumed in nsICommandLineHandler:handle
// to avoid issues on macos. See Marionette.jsm::handle() for more details.
// TODO: remove after Bug 1724251 is fixed.
try {
cmdLine.handleFlagWithParam("remote-debugging-port", false);
@@ -394,6 +395,9 @@ class RemoteAgentParentProcess {
Services.obs.addObserver(this, "mail-idle-startup-tasks-finished");
Services.obs.addObserver(this, "quit-application");
+ // Apply the common set of preferences for all supported protocols
+ lazy.RecommendedPreferences.applyPreferences();
+
// With Bug 1717899 we will extend the lifetime of the Remote Agent to
// the whole Firefox session, which will be identical to Marionette. For
// now prevent logging if the component is not enabled during startup.
@@ -484,12 +488,6 @@ class RemoteAgentParentProcess {
}
class RemoteAgentContentProcess {
- #classID;
-
- constructor() {
- this.#classID = Components.ID("{8f685a9d-8181-46d6-a71d-869289099c6d}");
- }
-
get running() {
let reply = Services.cpmm.sendSyncMessage("RemoteAgent:IsRunning");
if (!reply.length) {
@@ -166,7 +167,7 @@ class RemoteAgentParentProcess {
handle(cmdLine) {
// remote-debugging-port has to be consumed in nsICommandLineHandler:handle
- // to avoid issues on macos. See Marionette.jsm::handle() for more details.
+ // to avoid issues on macos. See Marionette.sys.mjs::handle() for more details.
// TODO: remove after Bug 1724251 is fixed.
try {